@@ -29,7 +29,7 @@ def create_model(config, fun_control, **kwargs) -> object:
             dictionary containing the configuration for the hyperparameter tuning.
         fun_control (dict):
             dictionary containing control parameters for the hyperparameter tuning.
-        **kwargs:
+        **kwargs (Any):
             additional keyword arguments.
 
     Returns:
