@@ -14,7 +14,7 @@ def test_net_light_regression_class():
     test_loader = DataLoader(dataset, batch_size=BATCH_SIZE)
     val_loader = DataLoader(dataset, batch_size=BATCH_SIZE)
 
-    net_light_base = NetLightRegression(l1=128,
+    net_light_regression = NetLightRegression(l1=128,
                                         epochs=10,
                                         batch_size=BATCH_SIZE,
                                         initialization='xavier',
@@ -24,9 +24,8 @@ def test_net_light_regression_class():
                                         _L_in=10,
                                         _L_out=1)
     trainer = L.Trainer(max_epochs=2,  enable_progress_bar=False)
-    trainer.fit(net_light_base, train_loader)
-    trainer.validate(net_light_base, val_loader)
-    res = trainer.test(net_light_base, test_loader)
+    trainer.fit(net_light_regression, train_loader, val_loader)    
+    res = trainer.test(net_light_regression, test_loader)
     # test if the entry 'hp_metric' is in the res dict
     assert 'hp_metric' in res[0].keys()
 
